@@ -124,17 +124,17 @@ Mojolicious::Plugin::AssetPack::Pipe::CombineFile - Store combined and gzipped a
   $app->plugin('AssetPack::Che' => {
           pipes => [qw(Sass Css JavaScript CombineFile)],
           CombineFile => { gzip => {min_size => 1000},}, # pipe options
-          process => {
-            'foo.html'=>['templates/foo.html', 'templates/bar.html',],
+          process => [
+            ['foo.html'=>qw(templates/foo.html templates/bar.html)],
             ...,
-          },
+          ],
         });
 
 =head1 CONFIG
 
-B<CombineFile> determine config for this pipe module. Hashref has keys for format extensions and also:
+B<CombineFile> determine config for this pipe module. Hashref keys:
 
-B<gzip> - options.
+B<gzip> - hashref options.
 
 
 =head1 ROUTE
