@@ -175,12 +175,12 @@ Mojolicious::Plugin::AssetPack::Pipe::VueTemplateCompiler - if you like separate
 
   $app->plugin('AssetPack::Che' => {
           pipes => [qw(VueTemplateCompiler CombineFile)],
-          VueTemplateCompiler=>{enabled=>$ENV{MOJO_ASSETPACK_VueTemplateCompiler} || 0},
-          process => {
-            'js/dist/templates/app★.js?bla'=>['components/foo.vue.html', 'components/bar.vue.html',],
-            'app.js'=>[qw('js/dist/templates/app★.js components/foo.vue.js components/bar.vue.js)]
+          VueTemplateCompiler=>{enabled=>$ENV{MOJO_ASSETPACK_VUE_TEMPLATE_COMPILER} || 0},# pipe options
+          process => [
+            ['js/dist/templates/app★.js?bla'=>qw(components/foo.vue.html components/bar.vue.html)],
+            ['app.js'=>qw('js/dist/templates/app★.js components/foo.vue.js components/bar.vue.js)],
             ...,
-          },
+          ],
         });
 
 =head1 Обязательно REQUIRED
@@ -198,10 +198,9 @@ Mojolicious::Plugin::AssetPack::Pipe::VueTemplateCompiler - if you like separate
   $ perl -pi.bak -e 's/const\s+ATTRS\s+=\s+{\n/const ATTRS = {}, ATTRS000 = {\n/' /tmp/node_modules/parcel-bundler/src/assets/HTMLAsset.js
 
 
-
 =head1 Конфигурация CONFIG
 
-Обработка файлов-шаблонов B< <path|url>.vue.html > пойдет только (ONLY) в режиме development.
+Обработка файлов-шаблонов B<< \<path|url>.vue.html >> пойдет только (ONLY) в режиме development.
 
 Обработанные топики шаблонов сохраняются в пути этого топика относительно static L<https://metacpan.org/pod/Mojolicious#static>.
 
